import json
from pathlib import Path

from new_experiment.new_dependency_provider import get_experiment_repository
from new_experiment.utils.property_helper import PropertyHelper
from sziszapangma.model.model_creators import create_new_word


def load_nemo_asr_results(dataset_name: str):
    repository = get_experiment_repository(dataset_name)
    jsonl_path = Path.home() / f'.cache/asr_benchmark/{dataset_name}.json'
    language_code = dataset_name[:2]
    with open(jsonl_path, 'r') as reader:
        lines = reader.read().splitlines(keepends=False)
        for json_line in lines:
            old_property_name = f'nvidia_stt_{language_code}_conformer_transducer_large'
            repository.delete_property(old_property_name)
            parsed_json = json.loads(json_line)
            print(parsed_json['audio_filepath'].split('/')[-1])
            record_id = parsed_json['audio_filepath'].split('/')[-1][:-4]
            print(parsed_json['audio_filepath'].split('/')[-1][:-4])
            transcript = parsed_json['pred_text']
            asr_result = {
                "transcription": [create_new_word(it) for it in transcript.split()],
                "full_text": transcript,
                "words_time_alignment": None
            }
            property_name = PropertyHelper.asr_result(f'nvidia_stt_{language_code}_conformer_transducer_large')
            repository.update_property_for_key(record_id, property_name, asr_result)


if __name__ == '__main__':
    load_nemo_asr_results('de_google_fleurs')
    load_nemo_asr_results('de_minds14')
    load_nemo_asr_results('de_voxpopuli')
    load_nemo_asr_results('en_google_fleurs')
    load_nemo_asr_results('en_minds14')
    load_nemo_asr_results('en_voxpopuli')
    load_nemo_asr_results('es_google_fleurs')
    load_nemo_asr_results('es_minds14')
    load_nemo_asr_results('es_voxpopuli')
    load_nemo_asr_results('fr_google_fleurs')
    load_nemo_asr_results('fr_minds14')
    load_nemo_asr_results('fr_voxpopuli')
    load_nemo_asr_results('it_google_fleurs')
    load_nemo_asr_results('it_minds14')
    load_nemo_asr_results('it_voxpopuli')
